@@ -2,7 +2,7 @@
 ## calculate var(phat) at point pts
 
 ##return NAs at points outside polygon???
-varphat<-function(pts, dpts, y, p, h)
+varphat <- function(pts, dpts, y, p, h)
 {
     npts <- length(pts)/2
     n <- length(y)
@@ -13,10 +13,10 @@ varphat<-function(pts, dpts, y, p, h)
     yy <- ynames0[as.character(y)]
     c <- rep(1, npts)
     wrksp <- rep(0, n)
-    ans<-.C("varphat", as.double(pts), as.integer(npts), as.double(dpts),
+    ans<-.C("var_phat", as.double(pts), as.integer(npts), as.double(dpts),
             as.integer(yy), as.double(p), as.integer(n), as.double(h), as.integer(1),
-            as.double(c), as.integer(m), as.double(wrksp), varp=double(npts*m),
-	    PACKAGE="spatialkernel")$varp
+            as.double(c), as.integer(m), as.double(wrksp), pvar=double(npts*m), 
+            PACKAGE="spatialkernel")$pvar
     ans <- matrix(ans, ncol=m, dimnames=list(NULL, ynames))
     invisible(list(pvar=ans, pts=pts, dpts=dpts, y=y, h=h))
 }
