@@ -4,6 +4,6 @@ void cubtri_(double*, double*, int*, double*, double*,
 void pnpoly_(double*, double*, double*, double*, int*, int*);
 void circumcircle(double*, double*, double*, double*);
 void constrained(double*, int*, double*, double*, double*, int*, int*, int*);
-void adaptpoly(double*, int*, double*, int*, double*, int*, double*, 
+void adapt_poly(double*, int*, double*, int*, double*, int*, double*, 
 	       double*, double*, double*, double*, int*, int*, 
 	       int*, double*);
